package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.WorkerApplyMapper;
import com.ruoyi.system.domain.WorkerApply;
import com.ruoyi.system.service.IWorkerApplyService;

/**
 * 师傅申请记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class WorkerApplyServiceImpl implements IWorkerApplyService 
{
    @Autowired
    private WorkerApplyMapper workerApplyMapper;

    /**
     * 查询师傅申请记录
     * 
     * @param id 师傅申请记录主键
     * @return 师傅申请记录
     */
    @Override
    public WorkerApply selectWorkerApplyById(Long id)
    {
        return workerApplyMapper.selectWorkerApplyById(id);
    }

    /**
     * 查询师傅申请记录列表
     * 
     * @param workerApply 师傅申请记录
     * @return 师傅申请记录
     */
    @Override
    public List<WorkerApply> selectWorkerApplyList(WorkerApply workerApply)
    {
        return workerApplyMapper.selectWorkerApplyList(workerApply);
    }

    /**
     * 新增师傅申请记录
     * 
     * @param workerApply 师傅申请记录
     * @return 结果
     */
    @Override
    public int insertWorkerApply(WorkerApply workerApply)
    {
        return workerApplyMapper.insertWorkerApply(workerApply);
    }

    /**
     * 修改师傅申请记录
     * 
     * @param workerApply 师傅申请记录
     * @return 结果
     */
    @Override
    public int updateWorkerApply(WorkerApply workerApply)
    {
        return workerApplyMapper.updateWorkerApply(workerApply);
    }

    /**
     * 批量删除师傅申请记录
     * 
     * @param ids 需要删除的师傅申请记录主键
     * @return 结果
     */
    @Override
    public int deleteWorkerApplyByIds(Long[] ids)
    {
        return workerApplyMapper.deleteWorkerApplyByIds(ids);
    }

    /**
     * 删除师傅申请记录信息
     * 
     * @param id 师傅申请记录主键
     * @return 结果
     */
    @Override
    public int deleteWorkerApplyById(Long id)
    {
        return workerApplyMapper.deleteWorkerApplyById(id);
    }
}
