package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.Users;
import com.ruoyi.system.service.IUsersService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.WorkerApply;
import com.ruoyi.system.service.IWorkerApplyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 师傅申请记录Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/WorkerApply")
public class WorkerApplyController extends BaseController
{
    @Autowired
    private IWorkerApplyService workerApplyService;
    @Autowired
    private IUsersService  usersService;
    /**
     * 查询师傅申请记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerApply:list')")
    @GetMapping("/list")
    public TableDataInfo list(WorkerApply workerApply)
    {
        startPage();
        List<WorkerApply> list = workerApplyService.selectWorkerApplyList(workerApply);
for(WorkerApply data:list){
    Users users = usersService.selectUsersById(data.getUid());
    if (users!=null){
        data.setUname(users.getName());
    }
}

        return getDataTable(list);
    }

    /**
     * 导出师傅申请记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerApply:export')")
    @Log(title = "师傅申请记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WorkerApply workerApply)
    {
        List<WorkerApply> list = workerApplyService.selectWorkerApplyList(workerApply);
        ExcelUtil<WorkerApply> util = new ExcelUtil<WorkerApply>(WorkerApply.class);
        util.exportExcel(response, list, "师傅申请记录数据");
    }

    /**
     * 获取师傅申请记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerApply:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(workerApplyService.selectWorkerApplyById(id));
    }

    /**
     * 新增师傅申请记录
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerApply:add')")
    @Log(title = "师傅申请记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WorkerApply workerApply)
    {
        return toAjax(workerApplyService.insertWorkerApply(workerApply));
    }

    /**
     * 修改师傅申请记录
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerApply:edit')")
    @Log(title = "师傅申请记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WorkerApply workerApply)
    {
        return toAjax(workerApplyService.updateWorkerApply(workerApply));
    }

    /**
     * 删除师傅申请记录
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerApply:remove')")
    @Log(title = "师傅申请记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(workerApplyService.deleteWorkerApplyByIds(ids));
    }
}
